You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2016/10/21 15:01:34 UTC

[40/44] isis git commit: ISIS-1519: deprecates JdoColumnLength in the applib

ISIS-1519: deprecates JdoColumnLength in the applib


Project: http://git-wip-us.apache.org/repos/asf/isis/repo
Commit: http://git-wip-us.apache.org/repos/asf/isis/commit/43a2bd58
Tree: http://git-wip-us.apache.org/repos/asf/isis/tree/43a2bd58
Diff: http://git-wip-us.apache.org/repos/asf/isis/diff/43a2bd58

Branch: refs/heads/master
Commit: 43a2bd58da55b3e0aa2e2ffc3c05f57eac2598a9
Parents: 00ef021
Author: Dan Haywood <da...@haywood-associates.co.uk>
Authored: Sun Oct 16 07:35:28 2016 +0100
Committer: Dan Haywood <da...@haywood-associates.co.uk>
Committed: Sun Oct 16 07:35:28 2016 +0100

----------------------------------------------------------------------
 .../jdo/applib/service/JdoColumnLength.java     | 110 ++++++++++++++++++-
 1 file changed, 104 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/isis/blob/43a2bd58/core/applib/src/main/java/org/apache/isis/objectstore/jdo/applib/service/JdoColumnLength.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/objectstore/jdo/applib/service/JdoColumnLength.java b/core/applib/src/main/java/org/apache/isis/objectstore/jdo/applib/service/JdoColumnLength.java
index 0a863d3..02b4298 100644
--- a/core/applib/src/main/java/org/apache/isis/objectstore/jdo/applib/service/JdoColumnLength.java
+++ b/core/applib/src/main/java/org/apache/isis/objectstore/jdo/applib/service/JdoColumnLength.java
@@ -18,55 +18,153 @@
  */
 package org.apache.isis.objectstore.jdo.applib.service;
 
+/**
+ * @deprecated
+ */
+@Deprecated
 public final class JdoColumnLength {
 
     private JdoColumnLength() {
     }
 
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public final static int TRANSACTION_ID = 36;
-    // ie OID str (based on the defacto limit of a request URL in web browsers such as IE8)
-    public final static int BOOKMARK = 2000; 
+
+    /**
+     * ie OID str (based on the defacto limit of a request URL in web browsers such as IE8)
+     *
+     * @deprecated
+     */
+    @Deprecated
+    public final static int BOOKMARK = 2000;
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final int MEMBER_IDENTIFIER = 255;
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final int USER_NAME = 50;
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public final static int TARGET_CLASS = 50;
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public final static int TARGET_ACTION = 50;
-    
+
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final int DESCRIPTION = 254;
 
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final class SettingAbstract {
         private SettingAbstract(){}
-        
+
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int SETTING_KEY = 128;
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int SETTING_TYPE = 20;
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int VALUE_RAW = 255;
     }
 
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final class Command {
         private Command() {
         }
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int EXECUTE_IN = 10;
     }
 
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final class AuditEntry {
 
         private AuditEntry() {
         }
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int PROPERTY_ID = 50;
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int PROPERTY_VALUE = 255;
     }
-    
+
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final class PublishedEvent {
 
         private PublishedEvent() {
         }
-        
+
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int TITLE = 255;
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int EVENT_TYPE = 20;
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int STATE = 20;
     }
 
+    /**
+     * @deprecated
+     */
+    @Deprecated
     public static final class StatusMessage {
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int MESSAGE = 255;
+        /**
+         * @deprecated
+         */
+        @Deprecated
         public static final int URI = BOOKMARK;
     }